function A = hpfilt(p,lambda);


%proc hpfilt(p,lambda);
%   This procedure computes a pxp matrix A which, when premultiplying
%  any px1 matrix y, returns the cyclical component of the hpfilter
%  of series y with parameter lambda.
%
% Input:  lambda - hp filter parameter.
%     :   p     - dimension of data series
%
% Let y - data series
%    d - cyclical component
%     t - trend component
%
% First we define a matrix k such that
%   (I + lambda*k) t = y.
% Then
%   t = inv( I + lambda*k ) y.
%   d = ( I - inv(I+lamda*k) ) y  =  A y;
%
%Procedure returns (1) the pxp matrix ( I - inv(I+lambda*k) ).

k = zeros(p,p);

%@ fill 1st row of k @

k(1,1) = 1;
k(1,2) = -2;
k(1,3) = 1;

%@ fill 2nd row of k @

k(2,1) = -2;
k(2,2) = 5;
k(2,3) = -4;
k(2,4) = 1;

%@ fill rows 3 to p-2 of k @

v = [ 1 -4 6 -4 1];
j=3;
while j <= p-2;
   k(j,j-2:j+2) = v;
   j = j+1;
end;

%@ fill row p-1 of k @

k(p-1, p-3) = 1;
k(p-1, p-2) = -4;
k(p-1, p-1) = 5;
k(p-1, p) = -2;

%@ fill row p of k @

k(p,p-2) = 1;
k(p,p-1) = -2;
k(p,p)   = 1;

%@ get matrix A such that d = Ay @

i = eye(p);
ilk = i + lambda*k;
invilk = inv(ilk);

A = (i - invilk);


