function [A,B,V,kap,psi,P] = findcgg(beta,sig,phipi,phix,alpha,phi,theta,rho,del,lam,ve,vu,vtau)

%solution to model in Gali, Lopez-Salido, Valles, NBER WP 8768
%only difference is that inertia in taylor rule is permitted, with alpha
%being the inertia parameter
%  z(t) = [pi(t) x(t) r(t) rrst(t)]'
%here, pi(t) is log gross inflation, x(t) is log-deviation of output from its flexible price level,
%r(t) is the log, gross nominal interest rate, and rrst(t) is the log
%natural real rate
%  z(t) = A*z(t-1) + B*s(t)
%where s(t) = (da(t) u(t) tau(t))'
%V is the variance of z(t).
%
%utility function: c^(1-sig)/(1-sig) - exp(tau(t))*N^(1+phi)/(1+phi)
%tau(t) is a preference shocks with time series representation, tau(t) =
%lam*tau(t-1)+epstau(t), Eepstau(t)^2=vtau.
%production function for intermediate good: yt(i) = A(t)*Nt(i)
%dlog(A(t)) = rho*dlog(A(t-1)) + eps(t), Eeps(t)^2 = ve
%policy rule: rst(t) = -log(beta) + phipi*pi(t) + phix*x(t), pi(t) -
%inflation, x(t) output gap
% then, actual nominal interest rate, r(t), is
%  r(t) = alpha*r(t-1) + alpha*rst(t) + u(t),
%u(t) is the monetary policy shock, u(t) = rho*u(t-1) + epss(t), Eepss(t)^2=vu
%pi(t) = beta*Et[pi(t+1)] + kap * x(t), kap is a function of structural
%parameters, including theta, probability of not changing prices


kap=(1-theta)*(1-beta*theta)*(sig+phi)/theta;
psi=(1+phi)/(sig+phi);


al0=[beta 0 0 0
   1/sig 1 0 0
   0 0 0 0
   0 0 0 0];

al1=[-1 kap 0 0
   0 -1 -1/sig 1/sig
   (1-alpha)*phipi (1-alpha)*phix -1 0
   0 0 0 1];

al2=[0 0 0 0
   0 0 0 0
   0 0 alpha 0
   0 0 0 0];

bet0=zeros(4,3);

bet1=[0 0 0
    0 0 0
    0 1 0
    -sig*psi*rho 0 -(1-lam)/(sig+phi)];

alphas=[al0, al1, al2];

ne=[];

[ind,dropm,A] = solvea(alphas,0,ne);

betas=[bet0 bet1];

tau=ones(3,4);
PP=zeros(3,3);
PP(1,1)=rho;
PP(2,2)=del;
PP(3,3)=lam;

[B,P] = solveb(A,alphas,betas,PP,tau);

Vs=[ve/(1-rho^2) 0 0 
     0 vu/(1-del^2) 0 
     0 0 vtau/(1-lam^2)];

if abs(alpha) > .1e-5
    error('fatal (findcgg) wrong value of alpha')
end

V=B*Vs*B';