function [zz,a] = graph(ve,vu,vtau,P,phi,sig,psi,T,A,B,shk)

%zz(1,:) - log, gross inflation
%zz(2,:) - log deviation, output from natural rate ('output gap')
%zz(3,:) - log, gross nominal rate of interest
%zz(4,:) - log, real natural rate of interest
%shk = 1 tech shock, shk = 2 monetary policy shock, shk = 3 preference shock

epsil=zeros(3,T);
if shk == 1
    epsil(1,1)=sqrt(ve);
elseif shk == 2
    epsil(2,1)=sqrt(vu);
elseif shk == 3
    epsil(3,1)=sqrt(vtau);
end


s(:,1)=epsil(:,1);
zz(:,1)=B*s(:,1);

for ii = 2:T
    s(:,ii)=P*s(:,ii-1);
    zz(:,ii)=A*zz(:,ii-1)+B*s(:,ii);
end

subplot(331)
tt=0:T-1;
plot(tt,zz(1,:))
title('inflation')
axis tight
subplot(332)
plot(tt,zz(2,:))
axis tight
title('output gap')
subplot(333)
plot(tt,zz(4,:),tt,zz(3,:),'*',tt,zz(3,:))
legend('natural real rate','actual nominal rate')
axis tight
title('nominal rate')
subplot(334)
plot(tt,zz(4,:))
axis tight
title('natural real rate')

a(1)=s(1,1);
for ii = 2:T
    a(ii)=a(ii-1)+s(1,ii);
end

subplot(335)
if shk ~= 1;plot(tt,s(shk,:));end
if shk == 1   
    plot(tt,a)
    axis([0 tt(end) 0 max(ceil(10*sqrt(ve)/(1-P(1,1)))/10,sqrt(ve))]);
    title('log, technology')
    str='Dynamic Response to a Technology Shock';
end
if shk == 2
    axis([0 tt(end) 0 ceil(10*sqrt(vu))/10]);
    title('monetary policy shock')
    str='Dynamic Response to a Monetary Policy Shock';
end
if shk == 3
    axis([0 tt(end) 0 ceil(10*sqrt(vtau))/10]);
    title('preference shock')
    str='Dynamic Response to a Preference Shock';
end

subplot(336)
yst=psi*a-s(3,:)/(sig+phi);%natural output
plot(tt,yst,tt,zz(2,:)+yst,'*',tt,zz(2,:)+yst)
legend('natural output','actual output')
axis tight
title('output')

subplot(337)
nst=yst-a;
plot(tt,nst,tt,nst+zz(2,:),'*',tt,nst+zz(2,:))
legend('natural employment','actual employment')
title('employment')
axis tight

hout=suptitle(str);